==> neo4j-consistency-check-3.5.5-sources.jar: org/neo4j/consistency/checking/full/RelationshipIndexProcessor.java <==
/*
 * Copyright (c) 2002-2019 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.consistency.checking.full;

import java.util.List;

import org.neo4j.consistency.checking.index.IndexAccessors;
import org.neo4j.consistency.report.ConsistencyReporter;
import org.neo4j.kernel.impl.store.record.RelationshipRecord;
import org.neo4j.storageengine.api.schema.StoreIndexDescriptor;

public class RelationshipIndexProcessor extends RecordProcessor.Adapter<RelationshipRecord>
{
    private final ConsistencyReporter reporter;
    private final RelationshipToIndexCheck checker;

    RelationshipIndexProcessor( ConsistencyReporter reporter, IndexAccessors indexes, PropertyReader propertyReader,
            List<StoreIndexDescriptor> relationshipIndexes )
    {
        this.reporter = reporter;
        checker = new RelationshipToIndexCheck( relationshipIndexes, indexes, propertyReader );
    }

    @Override
    public void process( RelationshipRecord relationshipRecord )
    {
        reporter.forRelationship( relationshipRecord, checker );
    }
}

==> neo4j-consistency-check-4.1.1-sources.jar: org/neo4j/consistency/checking/full/RelationshipIndexProcessor.java <==
/*
 * Copyright (c) 2002-2020 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.consistency.checking.full;

import java.util.List;

import org.neo4j.consistency.checking.index.IndexAccessors;
import org.neo4j.consistency.report.ConsistencyReporter;
import org.neo4j.internal.schema.IndexDescriptor;
import org.neo4j.io.pagecache.tracing.cursor.PageCursorTracer;
import org.neo4j.kernel.impl.store.record.RelationshipRecord;

public class RelationshipIndexProcessor extends RecordProcessor.Adapter<RelationshipRecord>
{
    private final ConsistencyReporter reporter;
    private final RelationshipToIndexCheck checker;

    RelationshipIndexProcessor( ConsistencyReporter reporter, IndexAccessors indexes, PropertyReader propertyReader, List<IndexDescriptor> relationshipIndexes )
    {
        this.reporter = reporter;
        checker = new RelationshipToIndexCheck( relationshipIndexes, indexes, propertyReader );
    }

    @Override
    public void process( RelationshipRecord relationshipRecord, PageCursorTracer cursorTracer )
    {
        reporter.forRelationship( relationshipRecord, checker, cursorTracer );
    }
}
